#ifndef _np_tasks_h
  #define _np_tasks_h

//********************************************************************
//NP_Tasks : a non-preemptive tasking routine for Atari 8 bit in C
//Written for the CC65 C compiler.
//
//**Beta Version**
//Send complaints/ridicule and bugs to : danwinslow@cox.net
//or PM to danwinslow on atariage.
//**Beta Version**
//
//Implements a simple tasking scheme. Tasks must yield the processer
//voluntarly by periodically calling the np_yield() function. Tasks
//which do not do so ( including the main() task ) will block the 
//other tasks.
//
// Author : Dan Winslow, 2009
//          
//********************************************************************

  //Error return codes
  #define NP_TASK_TABLE_FULL   128
  #define NP_TASK_TABLE_EMPTY  129

  //number of tasks...task 0 is main task, so this
  //setting leaves 3 available.
  #define max_tasks 4

  //task main procedure template
  //i.e., a task returns void and has one void * parameter
  //your task function must match this format
  typedef void (*task_type)(void *data);

  //call this before any other tasking routines
  void          np_init_tasking( void );

  //inits a task. Task does not start until switched to via np_yield()
  //returns NP_TASK_TABLE_FULL if no slots are available
  //otherwise returns index ( 1..max_tasks ) of slot for task
  //task_ptr is the address of your task, data is pointer to 
  //arbitrary data and is available to the task.
  unsigned char np_init_task   ( task_type task_ptr, void *data );

  //this must be called periodically by tasks ( including main )
  void          np_yield       ( void );

  //returns number of runnable tasks
  unsigned char np_task_count( void );

  //sleeps and yields
  void          np_sleep( int jiffies );

  //global task shutdown - advisory only
  void np_shutdown( void );

  //informs a task it should terminate
  unsigned char np_terminate( void );

#endif

